@@ -32,7 +32,7 @@ class StatusService:
         token_validity = False
         try:
             decoded_token: Dict = jwt.decode(self.sifflet_config.token, options={"verify_signature": False})
-            expiration_time: datetime = datetime.datetime.fromtimestamp(decoded_token.get("exp"))
+            expiration_time: datetime.datetime = datetime.datetime.fromtimestamp(decoded_token.get("exp", 0))
             rich_print(f"Token expiration date = {expiration_time}")
             token_validity = self.api_rules.fetch_token_valid()
         except InvalidTokenError as err:
