@@ -1,4 +1,4 @@
-from typing import List
+from typing import List, Optional
 
 from rich.console import Console
 from rich.table import Table, Column
@@ -6,7 +6,7 @@ from rich.table import Table, Column
 from sifflet.logger import logger
 
 
-def show_table(table: List[dict], title: str = None) -> None:
+def show_table(table: List[dict], title: Optional[str] = None) -> None:
     """Utility to display rich tables"""
 
     if table:
